@@ -1,16 +1,13 @@
 # -*- encoding: binary -*-
-require 'time'
-
+# :enddoc:
 # Writes a Rack response to your client using the HTTP/1.1 specification.
 # You use it by simply doing:
 #
 #   status, headers, body = rack_app.call(env)
-#   http_response_write(socket, [ status, headers, body ])
+#   http_response_write(socket, status, headers, body)
 #
 # Most header correctness (including Content-Length and Content-Type)
 # is the job of Rack, with the exception of the "Date" and "Status" header.
-#
-# TODO: allow keepalive
 module Unicorn::HttpResponse
 
   # Every standard HTTP code mapped to the appropriate message.
@@ -21,20 +18,19 @@ module Unicorn::HttpResponse
   CRLF = "\r\n"
 
   # writes the rack_response to socket as an HTTP response
-  def http_response_write(socket, rack_response)
-    status, headers, body = rack_response
+  def http_response_write(socket, status, headers, body)
     status = CODES[status.to_i] || status
 
     if headers
       buf = "HTTP/1.1 #{status}\r\n" \
-            "Date: #{Time.now.httpdate}\r\n" \
+            "Date: #{httpdate}\r\n" \
             "Status: #{status}\r\n" \
             "Connection: close\r\n"
       headers.each do |key, value|
-        next if %r{\A(?:Date\z|Status\z|Connection\z)}i =~ key
+        next if %r{\A(?:Date\z|Connection\z)}i =~ key
         if value =~ /\n/
           # avoiding blank, key-only cookies with /\n+/
-          buf << value.split(/\n+/).map! { |v| "#{key}: #{v}\r\n" }.join('')
+          buf << value.split(/\n+/).map! { |v| "#{key}: #{v}\r\n" }.join
         else
           buf << "#{key}: #{value}\r\n"
         end
@@ -43,7 +39,6 @@ module Unicorn::HttpResponse
     end
 
     body.each { |chunk| socket.write(chunk) }
-    socket.close # flushes and uncorks the socket immediately
     ensure
       body.respond_to?(:close) and body.close
   end
